@@ -4,13 +4,6 @@ mod packets;
 use pcap::{Capture, Device};
 use clap::{Arg, App, SubCommand};
 
-fn is_i32(val: String) -> Result<(), String> {
-    match val.parse::<i32>() {
-        Ok(_) => Ok(()),
-        Err(err) => Err(err.to_string()),
-    }
-}
-
 fn main() { 
 
     let application = App::new("PacketDog")
@@ -28,19 +21,24 @@ fn main() {
             ).arg(Arg::with_name("save")
                 .short("s")
                 .long("save")
-                .takes_value(false)
+                .takes_value(true)
                 .help("Saves output to a file.")
+            ).arg(Arg::with_name("by-index")
+                .short("i")
+                .long("index")
+                .takes_value(true)
+                .help("Runs packet dog with a selected device index.")
             ).arg(Arg::with_name("device")
                 .short("d")
                 .long("device")
                 .takes_value(true)
                 .help("Selects a device to sniff")
-            ).arg(Arg::with_name("table")
-                .short("t")
-                .long("table")
+            ).arg(Arg::with_name("print-output")
+                .short("p")
+                .long("print")
                 .takes_value(false)
-                .help("Decides whether or not the new data should be put in a table.")
-        )
+                .help("Prints output to console, while saving to a file. Will be ignored unless the `--save` flag is present.")
+            )
         ).get_matches();
     
     if let Some(_matches) = application.subcommand_matches("run") {
@@ -64,23 +62,57 @@ fn main() {
             return;
         }
 
-        let mut thing = handler::Handler::new();
 
-        if let Some(device_arg) = _matches.value_of("device") {
+        let mut handler = handler::Handler::new();
 
-            devices.into_iter().for_each(|dev | {
-                if dev.name == device_arg {
-                    main_device.name = dev.name.to_owned();
-                    main_device.desc = dev.desc.to_owned();
+        if let Some(index) = _matches.value_of("by-index") {
+            
+            match index.parse::<usize>() {
+                Err(err) => {
+                    panic!("{}", err);
                 }
-            });
+                Ok(int) => {
+                    let device = devices.iter().nth(int);
 
+                    match device {
+                        Some(device) => {
+                            main_device.name = device.name.to_owned();
+                            main_device.desc = device.desc.to_owned();                            
+                        }
+                        None => {
+                            panic!("There was no device at the index `{}`", int.to_string())
+                        }
+                    }
+                }
+            }
+
+        } else {
+            if let Some(device_arg) = _matches.value_of("device") {
+
+                devices.into_iter().for_each(|dev | {
+                    if dev.name == device_arg {
+                        main_device.name = dev.name.to_owned();
+                        main_device.desc = dev.desc.to_owned();
+                    }
+                });
+
+            }
         }
 
         let cap = Capture::from_device(
             main_device
         ).unwrap().open().unwrap();
 
-        thing.parse(cap);
+
+        if let Some(_) = _matches.value_of("print-output") {
+            println!("here");
+            handler.print_output();
+        }
+
+        if let Some(name) = _matches.value_of("save") {
+            handler.save_file(name.to_string());
+        }
+
+        handler.parse(cap);
     }
 }
\ No newline at end of file
